USA crime rates as incidents/100,000 population by state for several categories of property and violent crimes from 1960 - 2014 (except for New York, which starts in 1965).
data("USAcrime")A data frame with 2745 observations on the following 12 variables.
Yearnumeric
Statea factor with state.abb as its levels
Populationestimated population, numeric
allViolentoverall estimated violent crime rate, numeric
Homicidenumeric
Rapenumeric
Robberynumeric
Assaultnumeric
allPropertyoverall estimated property crime rate, numeric
Burglarynumeric
Larcenynumeric
vehicleTheftnumeric
Note that these are estimates, and there are various caveats and inconsistencies in definitions and reporting methods among states and over time. Consult the source for details.